@@ -2,9 +2,11 @@ import base64
 import json
 from wcs.commons.auth import Auth
 from wcs.commons.config import MGR_URL
+from wcs.commons.config import logging_folder
 from wcs.commons.http import _post
 from wcs.commons.http import _get
 from wcs.commons.util import entry
+from wcs.commons.util import get_logger
 
 class PersistentFop(object):
 
@@ -12,6 +14,7 @@ class PersistentFop(object):
         self.bucket = bucket
         self.host = MGR_URL
         self.auth = auth
+        self.logger = get_logger(logging_folder, 'persistentfop')
       
     def build_op(self,cmd, first_arg, **kwargs):
         op = [cmd]
@@ -36,7 +39,10 @@ class PersistentFop(object):
 
     def fops_status(self, persistentId):
         url = 'http://{0}/status/get/prefop?persistentId={1}'.format(self.host, persistentId)
-        return _get(url=url)
+        self.logger.info('Start to get status of persistentId: %s', persistentId)
+        code, text = _get(url=url)
+        self.logger.info('The return code and text of status request is:%d %s', code, text)
+        return code, text
 
     def params(self,params):
         if params:
@@ -62,10 +68,10 @@ class PersistentFop(object):
             data['separate'] = 1
         url = 'http://{0}/fops'.format(self.host)
         headers,reqdata = self.headers(url,data)
+        self.logger.info('PersistentFops is %s', fops)
+        self.logger.info('Start to post persistentFops')
         code,text = _post(url=url, data=reqdata,headers=headers)
-        if code == 200:
-            return code,text
-        else:
-            return code,text
+        self.logger.info('The return code and text of persistentfops is:%d %s', code, text)
+        return code,text
 
 
