@@ -37,19 +37,22 @@ class RegUpload(object):
         
     def reg_upload(self, filepath):
         puturl = "http://{0}/{1}/{2}".format(PUT_URL,"file","upload")
-        filedir,filename = os.path.split(filepath)
-        self.fileds['file'] = open(filepath, 'rb')
+        if isinstance(filepath, str):
+            if os.path.exists(filepath) and os.path.isfile(filepath):
+                filedir,filename = os.path.split(filepath)
+                self.fileds['file'] = open(filepath, 'rb')
+            else:
+                self.logger.error('Please input a existing file')
+                return -1, 'Sorry ! We need a existing file to upload\n'
+        if isinstance(filepath, file):
+            self.fileds['file'] = filepath
         datagen, headers = multipart_encode_for_requests(self.fileds, cb=progress)     
         headers['Accept'] = "*/*"
-        if os.path.exists(filepath) and os.path.isfile(filepath):
-            try:
-                self.logger.info('File %s upload progress start!', filepath)
-                r = requests.post(url=puturl, headers=headers, data=datagen)
-            except Exception as e:
-                self.logger.error('There is exception in upload progress')
-                return -1, e
-            self.logger.info('The result of upload is: %d, %s', r.status_code, r.text)
-            return r.status_code, r.text
-        else:
-            self.logger.error('Please input a existing file')
-            return -1, 'Sorry ! We need a existing file to upload\n'
+        try:
+            self.logger.info('File %s upload progress start!', filepath)
+            r = requests.post(url=puturl, headers=headers, data=datagen)
+        except Exception as e:
+            self.logger.error('There is exception in upload progress')
+            return -1, e
+        self.logger.info('The result of upload is: %d, %s', r.status_code, r.text)
+        return r.status_code, r.text
