@@ -7,7 +7,7 @@ import os
 import time
 import requests
 import multiprocessing
-from multiprocessing.dummy import Pool as TheadPool
+from multiprocessing.dummy import Pool as ThreadPool
 
 from wcs.commons.config import PUT_URL
 from wcs.commons.config import _BLOCK_SIZE
@@ -18,13 +18,14 @@ from wcs.commons.config import mkblk_retries
 from wcs.commons.config import bput_retries
 from wcs.commons.config import mkfile_retries
 from wcs.commons.config import logging_folder
+from wcs.commons.config import Thread_num
 
 from wcs.commons.http import _post
 from wcs.commons.util import get_logger
 from wcs.commons.util import readfile
 from wcs.commons.util import file_to_stream
 from wcs.commons.util import GetUuid
-from .uploadprogressrecorder import UploadProgressRecorder
+from uploadprogressrecorder import UploadProgressRecorder
 
 record_lock = multiprocessing.Lock()
 
@@ -39,7 +40,10 @@ class SliceUpload(object):
         self.upload_progress_recorder = upload_progress_recorder
         self.modify_time = modify_time
         self.key = key
-        self.size = os.path.getsize(self.filepath)
+        if isinstance(self.filepath, str):
+            self.size = os.path.getsize(self.filepath)
+        if isinstance(self.filepath, file):
+            self.size = os.fstat(self.filepath.fileno()).st_size
         self.params = params
         self.num = self.size/_BLOCK_SIZE + 1
         self.status = []
@@ -119,7 +123,7 @@ class SliceUpload(object):
             self.progress = float(self.size - len(offsets) * _BLOCK_SIZE)/float(self.size)
             
             self.logger.info('Now start upload file blocks')
-            pool = TheadPool()
+            pool = ThreadPool(Thread_num)
             pool.map(self.make_block, offsets)
             pool.close()
             pool.join()
@@ -156,7 +160,10 @@ class SliceUpload(object):
         return url
 
     def make_block(self, offset):
-        openfile = file_to_stream(self.filepath)
+        if isinstance(self.filepath, str):
+            openfile = file_to_stream(self.filepath)
+        if isinstance(self.filepath, file):
+            openfile = self.filepath
         bput = readfile(openfile, offset, _BPUT_SIZE)
         url = self.mlkblock_url(offset)
         headers = self.block_headers(self.uploadBatch)
@@ -190,7 +197,8 @@ class SliceUpload(object):
             offset_next = offset + bputtext['offset']
             bput_next = readfile(inputfile, offset_next, _BPUT_SIZE)
             bputnum += 1
-        inputfile.close()
+        if isinstance(self.filepath, str):
+            inputfile.close()
         return offset, bputcode, bputtext['ctx']
       
     def block_url(self, size, blocknum):
